# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [{{initial_release}}] - {{initial_release_date}}


[Unreleased]: {{repo_url}}/compare/v{{initial_release}}...HEAD
[{{initial_release}}]: {{repo_url}}/releases/tag/v{{initial_release}}
